<?xml version="1.0" encoding="utf-8"?>

<!-- ***************
     by Michael 'Mithi' Cordes ( http://www.dvd-welt.de/privat/xsl.html ) 03.08.2009
     developed and tested with DVD Profiler Version 3.0 XML-export
     *************** -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:include href="templates/template-genres.xsl"/>
  <xsl:include href="templates/template-regions.xsl"/>
  <xsl:include href="templates/template-credits.xsl"/>

<xsl:output method="html" encoding="utf-8"/>

<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>

<xsl:template match="Collection">
<xsl:variable name="laufzeitsumme"><xsl:value-of select="sum(/Collection/DVD[count(CollectionNumber[text()]) &gt; 0]/RunningTime)"/></xsl:variable>
<xsl:variable name="laufzeittage"><xsl:value-of select="floor($laufzeitsumme div 1440)"/></xsl:variable>
<xsl:variable name="laufzeitstunde"><xsl:value-of select="floor(($laufzeitsumme - $laufzeittage * 1440 ) div 60)"/></xsl:variable>
<xsl:variable name="laufzeitminute"><xsl:value-of select="number($laufzeitsumme - $laufzeittage * 1440 - $laufzeitstunde * 60)"/></xsl:variable>

<xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html>
</xsl:text>
<html>
  <head>
    <title>Mithis ungesehene DVDs/BDs</title>
    <meta name="author" content="Michael Cordes"/>
    <link rel="stylesheet" type="text/css" href="/privat/dvd-list.css"/>
    <meta http-equiv="content-type" content="text/html; charset=utf-8"/>
    <link rel="shortcut icon" href="/privat/favicon.ico" type="image/x-icon"/>
  </head>
  <body>
    <h1>Mithis ungesehene DVDs/BDs</h1>
    <br/>
    <h3>Zur Zeit <xsl:value-of select="count(/Collection/DVD[contains(CollectionType/@IsPartOfOwnedCollection, 'true') and count(CollectionNumber[text()]) &gt; 0])"/> Titel</h3>
    <table class="box" cellpadding="0" summary="DVD Liste" align="center">
      <xsl:apply-templates select="DVD"><xsl:sort select="RunningTime" data-type="number"/><xsl:sort select="substring(translate(SortTitle,$ucletters,$lcletters),1,30)"/></xsl:apply-templates>
    </table>
    <h3><xsl:value-of select="sum(/Collection/DVD[count(CollectionNumber[text()]) &gt; 0]/RunningTime)"/> Minuten Laufzeit<br/>
    <xsl:text>&#x2259;</xsl:text>
    <xsl:value-of select="$laufzeittage"/>
    <xsl:text> Tag</xsl:text><xsl:if test="$laufzeittage &gt; 1"><xsl:text>e</xsl:text></xsl:if>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$laufzeitstunde"/>
    <xsl:text> Stunde</xsl:text><xsl:if test="$laufzeitstunde &gt; 1"><xsl:text>n</xsl:text></xsl:if>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$laufzeitminute"/>
    <xsl:text> Minute</xsl:text><xsl:if test="$laufzeitminute &gt; 1"><xsl:text>n</xsl:text></xsl:if>
	</h3>
    <h4>
      <xsl:element name="a">                                    
        <xsl:attribute name="href">
        <xsl:text>bestellt-collection.html</xsl:text>    
        </xsl:attribute>
        ( <xsl:value-of select="sum(/Collection/DVD[contains(CollectionType, 'Ordered') and contains(CountAs, '1')]/RunningTime)"/> Minuten Laufzeit bestellt bzw im Versand )
      </xsl:element>
    </h4>
  </body>
</html>
</xsl:template>


<xsl:template match="DVD">
<!-- Ungesehen Owned -->
  <xsl:if test="contains(CollectionType/@IsPartOfOwnedCollection, 'true') and count(CollectionNumber[text()]) &gt; 0">
       <tr>
         <td class="dvdtitle"><xsl:value-of select="Title"/>
           <xsl:if test="string-length(DistTrait)&gt;0">
             <br/><xsl:value-of select="DistTrait"/>
           </xsl:if>
         </td>
         <td class="dvdtitle">
           <xsl:if test="MediaTypes/BluRay='true'">
             <xsl:element name="img">
               <xsl:attribute name="src">
                 <xsl:text>pics/logo-bd-weiss.png</xsl:text>
               </xsl:attribute>
               <xsl:attribute name="alt">
                 <xsl:text>BD </xsl:text>
               </xsl:attribute>
             </xsl:element>
           </xsl:if>
           <xsl:if test="MediaTypes/DVD='true' and MediaTypes/BluRay='false'">
             <xsl:element name="img">
               <xsl:attribute name="src">
                 <xsl:text>pics/logo-dvd-weiss.png</xsl:text>
               </xsl:attribute>
               <xsl:attribute name="alt">
                 <xsl:text>DVD </xsl:text>
               </xsl:attribute>
             </xsl:element>
           </xsl:if>
         </td>
       </tr>
       <tr>
         <td>
           <table border="0" class="w100">
             <tr>
               <td colspan="2" class="dvddata"><xsl:apply-templates select="Credits"/></td>
             </tr>
             <tr>
               <td class="dvddata w50"><xsl:value-of select="RunningTime"/><xsl:text> min</xsl:text></td>
               <td class="dvddata w50"><xsl:apply-templates select="Regions"/></td>
             </tr>
             <tr>
               <td class="dvddata" colspan="2"><xsl:apply-templates select="Genres"/></td>
             </tr>
           </table>
         </td>
         <td class="dvddata"><xsl:call-template name="IMDB"/></td>
       </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="IMDB">
        <xsl:if test="string-length(Discs/Disc/Slot)&gt;0">
          <xsl:element name="a">
            <xsl:attribute name="href">
              <xsl:text>http://akas.imdb.com/title/tt</xsl:text>
              <xsl:value-of select="Discs/Disc/Slot"/>
              <xsl:text>/</xsl:text>
            </xsl:attribute>
            <xsl:element name="img">
              <xsl:attribute name="src">
                <xsl:text>pics/imdb-logo.png</xsl:text>
              </xsl:attribute>
              <xsl:attribute name="alt">
                <xsl:text>Link zur IMDb für </xsl:text>
                <xsl:value-of select="Title"/>
              </xsl:attribute>
            </xsl:element>
          </xsl:element>
        </xsl:if>
</xsl:template>

</xsl:stylesheet>

